@@ -17,11 +17,16 @@
 
 #include "config.h"
 
+#include <stdint.h>
+#include "epan/guid-utils.h"
+#include "epan/proto.h"
 #include "wslua.h"
 
 #include <epan/decode_as.h>
 #include <epan/exceptions.h>
 #include <epan/show_exception.h>
+#include <epan/dissectors/packet-dcerpc.h>
+#include <string.h>
 
 
 /* WSLUA_CONTINUE_MODULE Proto */
@@ -35,7 +40,7 @@ WSLUA_CLASS_DEFINE(Dissector,NOP);
 WSLUA_CONSTRUCTOR Dissector_get (lua_State *L) {
     /* Obtains a dissector reference by name. */
 #define WSLUA_ARG_Dissector_get_NAME 1 /* The name of the dissector. */
-    const gchar* name = luaL_checkstring(L,WSLUA_ARG_Dissector_get_NAME);
+    const char* name = luaL_checkstring(L,WSLUA_ARG_Dissector_get_NAME);
     Dissector d;
 
     if ((d = find_dissector(name))) {
@@ -48,8 +53,8 @@ WSLUA_CONSTRUCTOR Dissector_get (lua_State *L) {
 }
 
 /* Allow dissector key names to be sorted alphabetically. */
-static gint
-compare_dissector_key_name(gconstpointer dissector_a, gconstpointer dissector_b)
+static int
+compare_dissector_key_name(const void *dissector_a, const void *dissector_b)
 {
   return strcmp((const char*)dissector_a, (const char*)dissector_b);
 }
@@ -58,8 +63,6 @@ WSLUA_CONSTRUCTOR Dissector_list (lua_State *L) {
     /* Gets a Lua array table of all registered Dissector names.
 
        Note: This is an expensive operation, and should only be used for troubleshooting.
-
-       @since 1.11.3
      */
     GList* list = get_dissector_names();
     GList* elist = NULL;
@@ -166,15 +169,16 @@ WSLUA_CONSTRUCTOR DissectorTable_new (lua_State *L) {
 #define WSLUA_OPTARG_DissectorTable_new_UINAME 2 /* The name of the table in the user interface.
                                                     Defaults to the name given in `tablename`, but can be any string. */
 #define WSLUA_OPTARG_DissectorTable_new_TYPE 3 /* One of `ftypes.UINT8`, `ftypes.UINT16`,
-                                                  `ftypes.UINT24`, `ftypes.UINT32`, or
-                                                  `ftypes.STRING`.
+                                                  `ftypes.UINT24`, `ftypes.UINT32`,
+                                                  `ftypes.STRING`, `ftypes.NONE`,
+                                                  or `ftypes.GUID`.
                                                   Defaults to `ftypes.UINT32`. */
 #define WSLUA_OPTARG_DissectorTable_new_BASE 4 /* One of `base.NONE`, `base.DEC`, `base.HEX`,
                                                   `base.OCT`, `base.DEC_HEX` or `base.HEX_DEC`.
                                                   Defaults to `base.DEC`. */
 #define WSLUA_OPTARG_DissectorTable_new_PROTO 5 /* The <<lua_class_Proto,`Proto`>> object that uses this dissector table. */
-    const gchar* name = (const gchar*)luaL_checkstring(L,WSLUA_ARG_DissectorTable_new_TABLENAME);
-    const gchar* ui_name = (const gchar*)luaL_optstring(L,WSLUA_OPTARG_DissectorTable_new_UINAME,name);
+    const char* name = (const char*)luaL_checkstring(L,WSLUA_ARG_DissectorTable_new_TABLENAME);
+    const char* ui_name = (const char*)luaL_optstring(L,WSLUA_OPTARG_DissectorTable_new_UINAME,name);
     enum ftenum type = (enum ftenum)luaL_optinteger(L,WSLUA_OPTARG_DissectorTable_new_TYPE,FT_UINT32);
     unsigned base = (unsigned)luaL_optinteger(L,WSLUA_OPTARG_DissectorTable_new_BASE,BASE_DEC);
     DissectorTable dt;
@@ -194,12 +198,16 @@ WSLUA_CONSTRUCTOR DissectorTable_new (lua_State *L) {
         case FT_UINT32:
             break;
 
+        case FT_GUID:
+            base = BASE_HEX;
+            break;
+
         default:
             /* Calling WSLUA_OPTARG_ERROR raises a Lua error and
                returns from this function. */
             WSLUA_OPTARG_ERROR(
                     DissectorTable_new, TYPE,
-                    "must be ftypes.UINT{8,16,24,32}, ftypes.STRING or ftypes.NONE");
+                    "must be ftypes.UINT{8,16,24,32}, ftypes.STRING, ftypes.GUID or ftypes.NONE");
             break;
     }
 
@@ -213,10 +221,11 @@ WSLUA_CONSTRUCTOR DissectorTable_new (lua_State *L) {
     dt->table = (type == FT_NONE) ?
         register_decode_as_next_proto(proto_id, name, ui_name, NULL) :
         register_dissector_table(name, ui_name, proto_id, type, base);
+    dt->heur_list = NULL;
     dt->name = g_strdup(name);
     dt->ui_name = g_strdup(ui_name);
-    dt->created = TRUE;
-    dt->expired = FALSE;
+    dt->created = true;
+    dt->expired = false;
 
     lua_rawgeti(L, LUA_REGISTRYINDEX, dissectortable_table_ref);
     lua_pushstring(L, name);
@@ -228,13 +237,29 @@ WSLUA_CONSTRUCTOR DissectorTable_new (lua_State *L) {
 }
 
 WSLUA_CONSTRUCTOR DissectorTable_heuristic_new(lua_State *L) {
-    /* Creates a new heuristic `DissectorTable` for your dissector's use. Returns true iff table was created successfully. */
+    /* Creates a new heuristic `DissectorTable` for your dissector's use. Returns true if table was created successfully.
+     * XXX - Currently it always returns nil.
+
+       @since 4.2.0
+     */
 #define WSLUA_ARG_DissectorTable_heuristic_new_TABLENAME 1 /* The short name of the table. Use lower-case alphanumeric, dot, and/or underscores. */
-#define WSLUA_ARG_DissectorTable_heuristic_new_PROTO 2 /* The <<lua_class_Proto,`Proto`>> object that uses this dissector table. */
-    const gchar* name = (const gchar*)luaL_checkstring(L,WSLUA_ARG_DissectorTable_heuristic_new_TABLENAME);
-    Proto proto = checkProto(L, WSLUA_ARG_DissectorTable_heuristic_new_PROTO);
+#define WSLUA_OPTARG_DissectorTable_heuristic_new_UINAME 2 /* The name of the table in the user interface.
+                                                    Defaults to the name given in `tablename`, but can be any string. */
+#define WSLUA_ARG_DissectorTable_heuristic_new_PROTO 3 /* The <<lua_class_Proto,`Proto`>> object that uses this dissector table. */
+    const char* name = (const char*)luaL_checkstring(L,WSLUA_ARG_DissectorTable_heuristic_new_TABLENAME);
+    const char* ui_name = NULL;
+    Proto proto = NULL;
+    int proto_id = -1;
     heur_dissector_list_t list;
-    int proto_id = proto_get_id_by_short_name(proto->name);
+    int idx = WSLUA_OPTARG_DissectorTable_heuristic_new_UINAME;
+
+    if (lua_isstring(L, idx)) {
+        ui_name = luaL_checkstring(L, idx);
+        idx++;
+    }
+
+    proto = checkProto(L, idx);
+    proto_id = proto_get_id_by_short_name(proto->name);
 
     list = find_heur_dissector_list(name);
     if (list) {
@@ -242,7 +267,30 @@ WSLUA_CONSTRUCTOR DissectorTable_heuristic_new(lua_State *L) {
         return 0;
     }
 
-    register_heur_dissector_list(name, proto_id);
+
+    DissectorTable dt;
+    dt = (DissectorTable)g_malloc(sizeof(struct _wslua_distbl_t));
+    dt->table = NULL;
+    dt->heur_list = register_heur_dissector_list_with_description(name, ui_name, proto_id);
+    dt->name = g_strdup(name);
+    dt->ui_name = g_strdup(ui_name);
+    dt->created = true;
+    dt->expired = false;
+
+    lua_rawgeti(L, LUA_REGISTRYINDEX, dissectortable_table_ref);
+    lua_pushstring(L, name);
+    pushDissectorTable(L, dt);
+    lua_settable(L, -3);
+
+#if 0
+    /* Return nil because this is not a regular DissectorTable that could
+     * be used with _try, _set, _add, etc., and so we need to build checks
+     * into the functions similar to File and CaptureInfo so that it
+     * doesn't get used as one. However, not returning it means that it
+     * doesn't get properly garbage collected. */
+    pushDissectorTable(L, dt);
+    WSLUA_RETURN(1); /* The newly created DissectorTable. */
+#endif
     return 0;
 }
 
@@ -255,7 +303,7 @@ typedef struct dissector_tables_foreach_table_info {
 /* this is the DATFunc_table function used for dissector_all_tables_foreach_table()
    so we can get all dissector_table names. This pushes the name into a table at stack index 1 */
 static void
-dissector_tables_list_func(const gchar *table_name, const gchar *ui_name _U_, gpointer user_data) {
+dissector_tables_list_func(const char *table_name, const char *ui_name _U_, void *user_data) {
     dissector_tables_foreach_table_info_t *data = (dissector_tables_foreach_table_info_t*) user_data;
     lua_pushstring(data->L, table_name);
     lua_rawseti(data->L, 1, data->num);
@@ -267,14 +315,12 @@ WSLUA_CONSTRUCTOR DissectorTable_list (lua_State *L) {
        use for the first argument to DissectorTable.get().
 
        Note: This is an expensive operation, and should only be used for troubleshooting.
-
-       @since 1.11.3
      */
     dissector_tables_foreach_table_info_t data = { 1, L };
 
     lua_newtable(L);
 
-    dissector_all_tables_foreach_table(dissector_tables_list_func, (gpointer)&data,
+    dissector_all_tables_foreach_table(dissector_tables_list_func, (void *)&data,
                                        (GCompareFunc)compare_dissector_key_name);
 
     WSLUA_RETURN(1); /* The array table of registered DissectorTable names. */
@@ -283,7 +329,7 @@ WSLUA_CONSTRUCTOR DissectorTable_list (lua_State *L) {
 /* this is the DATFunc_heur_table function used for dissector_all_heur_tables_foreach_table()
    so we can get all heuristic dissector list names. This pushes the name into a table at stack index 1 */
 static void
-heur_dissector_tables_list_func(const gchar *table_name, struct heur_dissector_list *table _U_, gpointer user_data) {
+heur_dissector_tables_list_func(const char *table_name, struct heur_dissector_list *table _U_, void *user_data) {
     dissector_tables_foreach_table_info_t *data = (dissector_tables_foreach_table_info_t*) user_data;
     lua_pushstring(data->L, table_name);
     lua_rawseti(data->L, 1, data->num);
@@ -295,14 +341,12 @@ WSLUA_CONSTRUCTOR DissectorTable_heuristic_list (lua_State *L) {
        use for the first argument in Proto:register_heuristic().
 
        Note: This is an expensive operation, and should only be used for troubleshooting.
-
-       @since 1.11.3
      */
     dissector_tables_foreach_table_info_t data = { 1, L };
 
     lua_newtable(L);
 
-    dissector_all_heur_tables_foreach_table(heur_dissector_tables_list_func, (gpointer)&data, NULL);
+    dissector_all_heur_tables_foreach_table(heur_dissector_tables_list_func, (void *)&data, NULL);
 
     WSLUA_RETURN(1); /* The array table of registered heuristic list names */
 }
@@ -316,7 +360,7 @@ WSLUA_CONSTRUCTOR DissectorTable_try_heuristics (lua_State *L) {
 #define WSLUA_ARG_DissectorTable_try_heuristics_PINFO 3 /* The packet info. */
 #define WSLUA_ARG_DissectorTable_try_heuristics_TREE 4 /* The tree on which to add the protocol items. */
 
-    const gchar* name = luaL_checkstring(L,WSLUA_ARG_DissectorTable_try_heuristics_LISTNAME);
+    const char* name = luaL_checkstring(L,WSLUA_ARG_DissectorTable_try_heuristics_LISTNAME);
     Tvb tvb = checkTvb(L,WSLUA_ARG_DissectorTable_try_heuristics_TVB);
     Pinfo pinfo = checkPinfo(L,WSLUA_ARG_DissectorTable_try_heuristics_PINFO);
     TreeItem tree = checkTreeItem(L,WSLUA_ARG_DissectorTable_try_heuristics_TREE);
@@ -341,16 +385,17 @@ WSLUA_CONSTRUCTOR DissectorTable_get (lua_State *L) {
      Obtain a reference to an existing dissector table.
      */
 #define WSLUA_ARG_DissectorTable_get_TABLENAME 1 /* The short name of the table. */
-    const gchar* name = luaL_checkstring(L,WSLUA_ARG_DissectorTable_get_TABLENAME);
+    const char* name = luaL_checkstring(L,WSLUA_ARG_DissectorTable_get_TABLENAME);
     dissector_table_t table = find_dissector_table(name);
 
     if (table) {
         DissectorTable dt = (DissectorTable)g_malloc(sizeof(struct _wslua_distbl_t));
         dt->table = table;
+        dt->heur_list = NULL;
         dt->name = g_strdup(name);
         dt->ui_name = NULL;
-        dt->created = FALSE;
-        dt->expired = FALSE;
+        dt->created = false;
+        dt->expired = false;
 
         pushDissectorTable(L, dt);
     } else {
@@ -394,25 +439,87 @@ WSLUA_METHOD DissectorTable_add (lua_State *L) {
     type = get_dissector_table_selector_type(dt->name);
 
     if (type == FT_STRING) {
-        gchar* pattern = g_strdup(luaL_checkstring(L,WSLUA_ARG_DissectorTable_add_PATTERN));
+        char* pattern = g_strdup(luaL_checkstring(L,WSLUA_ARG_DissectorTable_add_PATTERN));
         dissector_add_string(dt->name, pattern,handle);
         g_free (pattern);
-    } else if ( type == FT_UINT32 || type == FT_UINT16 || type ==  FT_UINT8 || type ==  FT_UINT24 ) {
-        if (lua_isnumber(L, WSLUA_ARG_DissectorTable_add_PATTERN)) {
-            int port = (int)luaL_checkinteger(L, WSLUA_ARG_DissectorTable_add_PATTERN);
-            dissector_add_uint(dt->name, port, handle);
+    } else if (type == FT_GUID) {
+        /* Handle GUID type (assuming it is represented as a string in Lua) */
+        const char* guid_str = luaL_checkstring(L,WSLUA_ARG_DissectorTable_add_PATTERN);
+        fvalue_t* fval = fvalue_from_literal(type, guid_str, 0, NULL);
+        const e_guid_t* guid = fvalue_get_guid(fval);
+        guid_key gk = {*guid, 0};
+        /* The dcerpc.uuid table requires its own initializer */
+        if(strcmp(DCERPC_TABLE_NAME, dt->name) == 0) {
+            e_guid_t uuid;
+            memcpy(&uuid, guid, sizeof(e_guid_t));
+            dcerpc_init_from_handle(dissector_handle_get_protocol_index(handle), &uuid, 0, handle);
         } else {
-            /* Not a number, try as range */
-            const gchar* pattern = luaL_checkstring(L,WSLUA_ARG_DissectorTable_add_PATTERN);
+            dissector_add_guid(dt->name, &gk, handle);
+            guids_add_uuid(guid, dissector_handle_get_protocol_short_name(handle));
+        }
+    } else if ( type == FT_UINT32 || type == FT_UINT16 || type ==  FT_UINT8 || type ==  FT_UINT24 ) {
+        /* Either an integer or a range.
+         * For number literals, Lua only accepts "." as the decimal separator,
+         * but when converting strings to numbers, Lua will accept "." or the
+         * locale native separator, and when converting numbers to strings will
+         * use the locale native separator. (On Lua 5.2 and earlier, *only*
+         * the locale native separator may be accepted.) The behavior can be
+         * changed when compiling Lua, but generally isn't (and on UN*X we use
+         * system packages for Lua.)
+         *
+         * Some locales use "," as the decimal separator. range_convert_str
+         * expects "," to separate integers in ranges.
+         *
+         * We can either call setlocale(LC_NUMERIC, ...) to save, set, and
+         * restore the locale here (not thread safe), or try to work around it.
+         */
+        switch(lua_type(L, WSLUA_ARG_DissectorTable_add_PATTERN)) {
+        case LUA_TNUMBER:
+        {
+            /* Try to convert to an integer. Note that on Lua 5.3 and higher
+             * this fails for numbers that can't be converted exactly, unlike
+             * on Lua 5.2 where it simply casts. This can be changed at Lua
+             * compile time, but on UN*X systems we use system Lua packages.
+             */
+            uint32_t port = wslua_checkuint32(L, WSLUA_ARG_DissectorTable_add_PATTERN);
+            dissector_add_uint(dt->name, port, handle);
+            break;
+        }
+
+        case LUA_TSTRING:
+        {
+            /* Convert all strings to ranges without trying number conversion,
+             * so that on locales that use decimal commas "10,11" is a range
+             * not the number 10.11.
+             * Using a range works fine for numbers that are single integers,
+             * but note range_convert_str will reject strings like "10.0",
+             * whereas Lua checkinteger will convert it.
+             */
+            const char* pattern = luaL_checkstring(L,WSLUA_ARG_DissectorTable_add_PATTERN);
             range_t *range = NULL;
-            if (range_convert_str(NULL, &range, pattern, G_MAXUINT32) == CVT_NO_ERROR) {
+            if (range_convert_str(NULL, &range, pattern, UINT32_MAX) == CVT_NO_ERROR) {
                 dissector_add_uint_range(dt->name, range, handle);
             } else {
                 wmem_free (NULL, range);
                 WSLUA_ARG_ERROR(DissectorTable_add,PATTERN,"invalid integer or range");
-                return  0;
+                return 0;
             }
             wmem_free (NULL, range);
+            break;
+        }
+
+#if 0
+        /* Just don't allow UInt64 types, but if 64-bit integer tables get
+         * supported (#20207) we'll need something like: */
+        case LUA_TUSERDATA:
+            checkUInt64(L, checkUInt64(L, 1);
+            ...
+            break;
+#endif
+
+        default:
+            WSLUA_ARG_ERROR(DissectorTable_add,PATTERN,"invalid integer or range");
+            return 0;
         }
     } else {
         luaL_error(L,"Strange type %d for a DissectorTable",type);
@@ -422,11 +529,7 @@ WSLUA_METHOD DissectorTable_add (lua_State *L) {
 }
 
 WSLUA_METHOD DissectorTable_set (lua_State *L) {
-    /*
-     Clear all existing dissectors from a table and add a new dissector or a range of new dissectors.
-
-     @since 1.11.3
-     */
+    /* Clear all existing dissectors from a table and add a new dissector or a range of new dissectors. */
 #define WSLUA_ARG_DissectorTable_set_PATTERN 2 /* The pattern to match (either an integer, a integer range or a string depending on the table's type). */
 #define WSLUA_ARG_DissectorTable_set_DISSECTOR 3 /* The dissector to add (either a <<lua_class_Proto,`Proto`>> or a <<lua_class_Dissector,`Dissector`>>). */
 
@@ -456,19 +559,42 @@ WSLUA_METHOD DissectorTable_set (lua_State *L) {
     type = get_dissector_table_selector_type(dt->name);
 
     if (type == FT_STRING) {
-        const gchar* pattern = luaL_checkstring(L,WSLUA_ARG_DissectorTable_set_PATTERN);
+        const char* pattern = luaL_checkstring(L,WSLUA_ARG_DissectorTable_set_PATTERN);
         dissector_delete_all(dt->name, handle);
         dissector_add_string(dt->name, pattern,handle);
+    } else if (type == FT_GUID) {
+        /* Handle GUID type (assuming it is represented as a string in Lua) */
+        const char* guid_str = luaL_checkstring(L,WSLUA_ARG_DissectorTable_set_PATTERN);
+        fvalue_t* fval = fvalue_from_literal(type, guid_str, 0, NULL);
+        const e_guid_t* guid = fvalue_get_guid(fval);
+        guid_key gk = {*guid, 0};
+        /* The dcerpc.uuid table requires its own initializer */
+        if(strcmp(DCERPC_TABLE_NAME, dt->name) == 0) {
+            e_guid_t uuid;
+            memcpy(&uuid, guid, sizeof(e_guid_t));
+            dcerpc_init_from_handle(dissector_handle_get_protocol_index(handle), &uuid, 0, handle);
+        } else {
+            dissector_add_guid(dt->name, &gk, handle);
+            guids_add_uuid(guid, dissector_handle_get_protocol_short_name(handle));
+        }
     } else if ( type == FT_UINT32 || type == FT_UINT16 || type ==  FT_UINT8 || type ==  FT_UINT24 ) {
-        if (lua_isnumber(L, WSLUA_ARG_DissectorTable_set_PATTERN)) {
-            int port = (int)luaL_checkinteger(L, WSLUA_ARG_DissectorTable_set_PATTERN);
+        /* Either an integer or a range. See discussion above in _add. */
+        switch(lua_type(L, WSLUA_ARG_DissectorTable_set_PATTERN)) {
+
+        case LUA_TNUMBER:
+        {
+            uint32_t port = wslua_checkuint32(L, WSLUA_ARG_DissectorTable_set_PATTERN);
             dissector_delete_all(dt->name, handle);
             dissector_add_uint(dt->name, port, handle);
-        } else {
-            /* Not a number, try as range */
-            const gchar* pattern = luaL_checkstring(L,WSLUA_ARG_DissectorTable_set_PATTERN);
+            break;
+        }
+
+        case LUA_TSTRING:
+        {
+            /* Convert all strings to ranges */
+            const char* pattern = luaL_checkstring(L,WSLUA_ARG_DissectorTable_set_PATTERN);
             range_t *range = NULL;
-            if (range_convert_str(NULL, &range, pattern, G_MAXUINT32) == CVT_NO_ERROR) {
+            if (range_convert_str(NULL, &range, pattern, UINT32_MAX) == CVT_NO_ERROR) {
                 dissector_delete_all(dt->name, handle);
                 dissector_add_uint_range(dt->name, range, handle);
             } else {
@@ -477,6 +603,12 @@ WSLUA_METHOD DissectorTable_set (lua_State *L) {
                 return 0;
             }
             wmem_free (NULL, range);
+            break;
+        }
+
+        default:
+            WSLUA_ARG_ERROR(DissectorTable_set,PATTERN,"invalid integer or range");
+            return 0;
         }
     } else {
         luaL_error(L,"Strange type %d for a DissectorTable",type);
@@ -512,25 +644,47 @@ WSLUA_METHOD DissectorTable_remove (lua_State *L) {
     type = get_dissector_table_selector_type(dt->name);
 
     if (type == FT_STRING) {
-        gchar* pattern = g_strdup(luaL_checkstring(L,WSLUA_ARG_DissectorTable_remove_PATTERN));
+        char* pattern = g_strdup(luaL_checkstring(L,WSLUA_ARG_DissectorTable_remove_PATTERN));
         dissector_delete_string(dt->name, pattern,handle);
         g_free (pattern);
+    } else if (type == FT_GUID) {
+        // Handle GUID type (assuming it is represented as a string in Lua)
+        const char* guid_str = luaL_checkstring(L,WSLUA_ARG_DissectorTable_remove_PATTERN);
+        fvalue_t* fval = fvalue_from_literal(type, guid_str, 0, NULL);
+        const e_guid_t* guid = fvalue_get_guid(fval);
+        guid_key gk = {*guid, 0};
+        guids_delete_guid(guid);
+        dissector_delete_guid(dt->name, &gk, handle);
     } else if ( type == FT_UINT32 || type == FT_UINT16 || type ==  FT_UINT8 || type ==  FT_UINT24 ) {
-        if (lua_isnumber(L, WSLUA_ARG_DissectorTable_remove_PATTERN)) {
-          int port = (int)luaL_checkinteger(L, WSLUA_ARG_DissectorTable_remove_PATTERN);
-          dissector_delete_uint(dt->name, port, handle);
-        } else {
-            /* Not a number, try as range */
-            const gchar* pattern = luaL_checkstring(L,WSLUA_ARG_DissectorTable_remove_PATTERN);
+        /* Either an integer or a range. See discussion above in _add. */
+        switch(lua_type(L, WSLUA_ARG_DissectorTable_set_PATTERN)) {
+
+        case LUA_TNUMBER:
+        {
+            uint32_t port = wslua_checkuint32(L, WSLUA_ARG_DissectorTable_set_PATTERN);
+            dissector_delete_uint(dt->name, port, handle);
+            break;
+        }
+
+        case LUA_TSTRING:
+        {
+            /* Convert all strings to ranges */
+            const char* pattern = luaL_checkstring(L,WSLUA_ARG_DissectorTable_remove_PATTERN);
             range_t *range = NULL;
-            if (range_convert_str(NULL, &range, pattern, G_MAXUINT32) == CVT_NO_ERROR)
+            if (range_convert_str(NULL, &range, pattern, UINT32_MAX) == CVT_NO_ERROR) {
                 dissector_delete_uint_range(dt->name, range, handle);
-            else {
+            } else {
                 wmem_free (NULL, range);
                 WSLUA_ARG_ERROR(DissectorTable_remove,PATTERN,"invalid integer or range");
                 return 0;
             }
             wmem_free (NULL, range);
+            break;
+        }
+
+        default:
+            WSLUA_ARG_ERROR(DissectorTable_remove,PATTERN,"invalid integer or range");
+            return 0;
         }
     }
 
@@ -538,11 +692,7 @@ WSLUA_METHOD DissectorTable_remove (lua_State *L) {
 }
 
 WSLUA_METHOD DissectorTable_remove_all (lua_State *L) {
-    /*
-     Remove all dissectors from a table.
-
-     @since 1.11.3
-     */
+    /* Remove all dissectors from a table. */
 #define WSLUA_ARG_DissectorTable_remove_all_DISSECTOR 2 /* The dissector to remove (either a <<lua_class_Proto,`Proto`>> or a <<lua_class_Dissector,`Dissector`>>). */
     DissectorTable dt = checkDissectorTable(L,1);
     Dissector handle;
@@ -579,8 +729,8 @@ WSLUA_METHOD DissectorTable_try (lua_State *L) {
     Pinfo pinfo = checkPinfo(L,WSLUA_ARG_DissectorTable_try_PINFO);
     TreeItem ti = checkTreeItem(L,WSLUA_ARG_DissectorTable_try_TREE);
     ftenum_t type;
-    gboolean handled = FALSE;
-    const gchar *volatile error = NULL;
+    bool handled = false;
+    const char *volatile error = NULL;
     int len = 0;
 
     if (! (dt && tvb && tvb->ws_tvb && pinfo && ti) ) return 0;
@@ -590,18 +740,33 @@ WSLUA_METHOD DissectorTable_try (lua_State *L) {
     TRY {
 
         if (type == FT_STRING) {
-            const gchar* pattern = luaL_checkstring(L,WSLUA_ARG_DissectorTable_try_PATTERN);
+            const char* pattern = luaL_checkstring(L,WSLUA_ARG_DissectorTable_try_PATTERN);
 
             len = dissector_try_string(dt->table,pattern,tvb->ws_tvb,pinfo->ws_pinfo,ti->tree, NULL);
             if (len > 0) {
-                handled = TRUE;
+                handled = true;
+            }
+        } else if ( type == FT_GUID ) {
+            const char* guid_str = luaL_checkstring(L,WSLUA_ARG_DissectorTable_try_PATTERN);
+            fvalue_t* fval = fvalue_from_literal(type, guid_str, 0, NULL);
+            const e_guid_t* guid = fvalue_get_guid(fval);
+            guid_key gk = {*guid, 0};
+
+            len = dissector_try_guid(dt->table, &gk,tvb->ws_tvb,pinfo->ws_pinfo,ti->tree);
+            if (len > 0) {
+                handled = true;
             }
         } else if ( type == FT_UINT32 || type == FT_UINT16 || type ==  FT_UINT8 || type ==  FT_UINT24 ) {
-            int port = (int)luaL_checkinteger(L, WSLUA_ARG_DissectorTable_try_PATTERN);
+            uint32_t port = wslua_checkuint32(L, WSLUA_ARG_DissectorTable_try_PATTERN);
 
             len = dissector_try_uint(dt->table,port,tvb->ws_tvb,pinfo->ws_pinfo,ti->tree);
             if (len > 0) {
-                handled = TRUE;
+                handled = true;
+            }
+	} else if ( type == FT_NONE ) {
+	    len = dissector_try_payload(dt->table,tvb->ws_tvb,pinfo->ws_pinfo,ti->tree);
+	    if (len > 0) {
+	        handled = true;
             }
         } else {
             error = "No such type of dissector table";
@@ -637,10 +802,16 @@ WSLUA_METHOD DissectorTable_get_dissector (lua_State *L) {
     type = get_dissector_table_selector_type(dt->name);
 
     if (type == FT_STRING) {
-        const gchar* pattern = luaL_checkstring(L,WSLUA_ARG_DissectorTable_get_dissector_PATTERN);
+        const char* pattern = luaL_checkstring(L,WSLUA_ARG_DissectorTable_get_dissector_PATTERN);
         handle = dissector_get_string_handle(dt->table,pattern);
+    } else if ( type == FT_GUID ) {
+        const char* guid_str = luaL_checkstring(L,WSLUA_ARG_DissectorTable_get_dissector_PATTERN);
+        fvalue_t* fval = fvalue_from_literal(type, guid_str, 0, NULL);
+        const e_guid_t* guid = fvalue_get_guid(fval);
+        guid_key gk = {*guid, 0};
+        handle = dissector_get_guid_handle(dt->table,&gk);
     } else if ( type == FT_UINT32 || type == FT_UINT16 || type ==  FT_UINT8 || type ==  FT_UINT24 ) {
-        int port = (int)luaL_checkinteger(L, WSLUA_ARG_DissectorTable_get_dissector_PATTERN);
+        uint32_t port = wslua_checkuint32(L, WSLUA_ARG_DissectorTable_get_dissector_PATTERN);
         handle = dissector_get_uint_handle(dt->table,port);
     }
 
@@ -657,8 +828,6 @@ WSLUA_METHOD DissectorTable_add_for_decode_as (lua_State *L) {
     /*
      Add the given <<lua_class_Proto,`Proto`>> to the “Decode as...” list for this DissectorTable.
      The passed-in <<lua_class_Proto,`Proto`>> object's `dissector()` function is used for dissecting.
-
-     @since 1.99.1
      */
 #define WSLUA_ARG_DissectorTable_add_for_decode_as_PROTO 2 /* The <<lua_class_Proto,`Proto`>> to add. */
     DissectorTable dt = checkDissectorTable(L,1);
@@ -703,6 +872,11 @@ WSLUA_METAMETHOD DissectorTable__tostring(lua_State* L) {
             g_string_append_printf(s,"%s Integer(%i):\n",dt->name,base);
             break;
         }
+        case FT_GUID:
+        {
+            g_string_append_printf(s,"%s GUID:\n",dt->name);
+            break;
+        }
         case FT_NONE:
         {
             g_string_append_printf(s,"%s only for Decode As:\n",dt->name);
@@ -723,7 +897,7 @@ static int DissectorTable__gc(lua_State* L) {
 
     if (dt->created && !dt->expired) {
         /* Created DissectorTable will pass GC two times */
-        dt->expired = TRUE;
+        dt->expired = true;
     } else {
         g_free((char *)dt->name);
         g_free((char *)dt->ui_name);
@@ -770,7 +944,12 @@ int wslua_deregister_dissector_tables(lua_State* L) {
     for (lua_pushnil(L); lua_next(L, -2); lua_pop(L, 1)) {
         DissectorTable dt = checkDissectorTable(L, -1);
         if (dt->created) {
-            deregister_dissector_table(dt->name);
+            if (dt->table) {
+                deregister_dissector_table(dt->name);
+            }
+            if (dt->heur_list) {
+                deregister_heur_dissector_list(dt->name);
+            }
         }
     }
 
@@ -779,6 +958,7 @@ int wslua_deregister_dissector_tables(lua_State* L) {
     return 0;
 }
 
+
 /*
  * Editor modelines  -  https://www.wireshark.org/tools/modelines.html
  *
